#!/usr/bin/env python

"""
****************************************************************************
 treeline.py, the main program file

 TreeLine, an information storage program
 Copyright (C) 2005, Douglas W. Bell

 This is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License, Version 2.  This program is
 distributed in the hope that it will be useful, but WITTHOUT ANY WARRANTY.
*****************************************************************************
"""

__progname__ = 'TreeLine'
__version__ = '0.12.0'
__author__ = 'Doug Bell'

helpFilePath = '/usr/local/share/doc/treeline'   # modified by install script
iconPath =  '/usr/local/share/treeline/icons'   # modified by install script

import sys, getopt
import treedoc, cmdline
from cmdline import CmdLine

def main():
    if not treedoc.testXmlParser():
        from qt import QApplication, QMessageBox
        app = QApplication(sys.argv)
        QMessageBox.critical(None, 'Error', \
                             'Error loading XML Parser\n'\
                             'See TreeLine ReadMe file', 1, 0)
        sys.exit(3)
    treedoc.setLocalEncoding()
    try:
        split = sys.argv.index('--')
        qtOpts, args = sys.argv[:split], sys.argv[split+1:]
    except ValueError:
        qtOpts, args = sys.argv[:1], sys.argv[1:]
    try:
        opts, args = getopt.gnu_getopt(args, CmdLine.options, \
                                       CmdLine.longOptions)
    except getopt.GetoptError:
        print cmdline.__doc__
        sys.exit(2)

    if opts:
        CmdLine(opts, args)
    else:
        from treemainwin import TreeMainWin
        from qt import QApplication

        app = QApplication(qtOpts)
        win = TreeMainWin()
        app.setMainWidget(win)
        if args:
            win.openFile(args[0])
        else:
            win.autoOpen()
        win.show()
        win.lateInit()
        app.exec_loop()


if __name__ == '__main__':
    main()
